@@ -1,22 +1,7 @@
 /*
-  This file is part of the KDE Help Center
+    SPDX-FileCopyrightText: 2016 Pino Toscano <pino@kde.org>
 
-  Copyright (c) 2016 Pino Toscano <pino@kde.org>
-
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
-  MA  02110-1301, USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "cachereader.h"
@@ -105,11 +90,7 @@ bool CacheReader::parse( const QString& file )
 
 QSet<QString> CacheReader::documents() const
 {
-#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-  return QSet<QString>::fromList( mRanges.uniqueKeys() );
-#else
   return QSet<QString>( mRanges.keyBegin(), mRanges.keyEnd() );
-#endif
 }
 
 QByteArray CacheReader::document( const QString& id ) const
@@ -123,12 +104,11 @@ QByteArray CacheReader::document( const QString& id ) const
 
   if ( docRanges.count() == 1 ) {
     const Range range = docRanges.first();
-    doc = mText.midRef( range.first, range.second - range.first + 1 ).toUtf8();
+    doc = QStringView(mText).mid( range.first, range.second - range.first + 1 ).toUtf8();
   } else {
     std::reverse( docRanges.begin(), docRanges.end() );
     QTextStream stream( &doc );
-    stream.setCodec( "UTF-8" );
-    for ( const Range &range : qAsConst(docRanges) ) {
+    for ( const Range &range : std::as_const(docRanges) ) {
       stream << mText.mid( range.first, range.second - range.first + 1 );
     }
   }
